# openapi-doc

Programmatically builds an Open API (Swagger 2.0) document as an Express endpoint so that the documentation and source can live together in one place.  It is like annotating an Express endpoint.  Later, the API can be bound to Express.

[![build status](https://git.ecd.axway.int/jpeabody/openapi-doc/badges/master/build.svg)](https://git.ecd.axway.int/jpeabody/openapi-doc/commits/master)
[![coverage report](https://git.ecd.axway.int/jpeabody/openapi-doc/badges/master/coverage.svg)](https://git.ecd.axway.int/jpeabody/openapi-doc/commits/master)

## Features

* Programmatically define an Open API (Swagger 2.0) API.
* Generates a syntactically correct Swagger API JSON document from source.
* Swagger API document can be served via Express.

## Install

`npm install --save openapi-doc`

# API Reference

Open API documentation for node.js and Express.js

**Example** *(Quick start)*  
```javascript
    const Swagger = require('openapi-doc');
    const swagger = new Swagger();
    swagger.info('My API', '1.0', 'This is *API*');

    // describe API endpoint and action
    swagger.get('/logs')
        .operationId('getLogs')
        .tag('logging')
        .summary('Gets an array of logs.')
        .response(200)
        .action((req, res) => {
            res.sendStatus(200);
        });
```
**Example** *(Bind API to Express endpoint)*  
```javascript
    const prefix = '/api';
    Swagger.forEachAction(swagger, (verb, path) => {
        const endpoint = Swagger.endpointToExpress(prefix + path);
        // express app
        app[verb](
            endpoint,
            Swagger.actionMiddleware(swagger, verb, path)
        );
    });
```
**Example** *(Apply security)*  
```javascript
    const prefix = '/api';
    swagger.securityDefinition(
        'basicAuth', {
            type: 'basic',
            description: 'Username and password',
        },
        (req) => {
            return true;
        }
    );
    Swagger.forEachAction(swagger, (verb, path) => {
        const endpoint = Swagger.endpointToExpress(prefix + path);
        // express app
        app[verb](
            endpoint,
            Swagger.securityMiddleware(swagger, verb, path),
            Swagger.actionMiddleware(swagger, verb, path)
        );
    });
```
**Example** *(Bind generated Swagger API document to Express endpoint)*  
```javascript
    app.get('/api-doc', function (req, resp) {
        resp.send(swagger.apidoc());
    });
```
<a name="module_openapi-doc..Swagger"></a>

### openapi-doc~Swagger
**Kind**: inner class of <code>[openapi-doc](#module_openapi-doc)</code>  

* [~Swagger](#module_openapi-doc..Swagger)
    * [new Swagger()](#new_module_openapi-doc..Swagger_new)
    * _instance_
        * [.securityHandlers](#module_openapi-doc..Swagger+securityHandlers) ⇒ <code>object</code>
        * [.actions](#module_openapi-doc..Swagger+actions) ⇒ <code>object</code>
        * [.info(title, version, description)](#module_openapi-doc..Swagger+info) ⇒ <code>Swagger</code>
        * [.host(name)](#module_openapi-doc..Swagger+host)
        * [.license(name)](#module_openapi-doc..Swagger+license)
        * [.contact(name, [email])](#module_openapi-doc..Swagger+contact)
        * [.termsOfService(name)](#module_openapi-doc..Swagger+termsOfService)
        * [.basePath(path)](#module_openapi-doc..Swagger+basePath)
        * [.schemes(schemes)](#module_openapi-doc..Swagger+schemes)
        * [.securityDefinition(options, handler)](#module_openapi-doc..Swagger+securityDefinition) ⇒ <code>Swagger</code>
        * [.security(definitionNames)](#module_openapi-doc..Swagger+security) ⇒ <code>Swagger</code>
        * [.nosecurity()](#module_openapi-doc..Swagger+nosecurity)
        * [.schema(name, spec)](#module_openapi-doc..Swagger+schema) ⇒ <code>Swagger</code>
        * [.schemas()](#module_openapi-doc..Swagger+schemas)
        * [.post(path)](#module_openapi-doc..Swagger+post) ⇒ <code>Swagger</code>
        * [.get(path)](#module_openapi-doc..Swagger+get) ⇒ <code>Swagger</code>
        * [.put(path)](#module_openapi-doc..Swagger+put) ⇒ <code>Swagger</code>
        * [.delete(path)](#module_openapi-doc..Swagger+delete) ⇒ <code>Swagger</code>
        * [.patch(path)](#module_openapi-doc..Swagger+patch) ⇒ <code>Swagger</code>
        * [.summary(summary)](#module_openapi-doc..Swagger+summary) ⇒ <code>Swagger</code>
        * [.description(description)](#module_openapi-doc..Swagger+description) ⇒ <code>Swagger</code>
        * [.operationId(name)](#module_openapi-doc..Swagger+operationId) ⇒ <code>Swagger</code>
        * [.tag(name)](#module_openapi-doc..Swagger+tag) ⇒ <code>Swagger</code>
        * [.tags(tags)](#module_openapi-doc..Swagger+tags) ⇒ <code>Swagger</code>
        * [.body(type, description)](#module_openapi-doc..Swagger+body) ⇒ <code>Swagger</code>
        * [.parameter(param)](#module_openapi-doc..Swagger+parameter) ⇒ <code>Swagger</code>
        * [.parameters(parameters)](#module_openapi-doc..Swagger+parameters)
        * [.consumes(mimeType, forceGlobal)](#module_openapi-doc..Swagger+consumes) ⇒ <code>Swagger</code>
        * [.produces(mimeType, forceGlobal)](#module_openapi-doc..Swagger+produces) ⇒ <code>Swagger</code>
        * [.response(code, [description], [type], [isArray], [headers])](#module_openapi-doc..Swagger+response) ⇒ <code>Swagger</code>
        * [.responses(repsonses)](#module_openapi-doc..Swagger+responses)
        * [.action(handler)](#module_openapi-doc..Swagger+action) ⇒ <code>Swagger</code>
        * [.merge(swagger, [prefix])](#module_openapi-doc..Swagger+merge)
        * [.paths(paths, [prefix])](#module_openapi-doc..Swagger+paths)
        * [.apidoc()](#module_openapi-doc..Swagger+apidoc) ⇒ <code>object</code>
    * _static_
        * [.endpointToExpress(str)](#module_openapi-doc..Swagger.endpointToExpress) ⇒ <code>string</code>
        * [.forEachAction(swagger, callback)](#module_openapi-doc..Swagger.forEachAction)
        * [.actionMiddleware(swagger, verb, path)](#module_openapi-doc..Swagger.actionMiddleware)
        * [.securityMiddleware(swagger, verb, path)](#module_openapi-doc..Swagger.securityMiddleware)

<a name="new_module_openapi-doc..Swagger_new"></a>

#### new Swagger()
Construct a Swagger builder.

<a name="module_openapi-doc..Swagger+securityHandlers"></a>

#### swagger.securityHandlers ⇒ <code>object</code>
Returns all of the security handlers associated with the API endpoints.

**Kind**: instance property of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>object</code> - Map of callback functions.  
**Access**: public  
**Example**  
```js
Object.keys(swagger.securityHandlers, (key) => {
    swagger.securityHandlers[key];
});
```
<a name="module_openapi-doc..Swagger+actions"></a>

#### swagger.actions ⇒ <code>object</code>
Returns all of the actions associated with the API endpoints.

**Kind**: instance property of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>object</code> - Map of [path][verb].  
**Access**: public  
<a name="module_openapi-doc..Swagger+info"></a>

#### swagger.info(title, version, description) ⇒ <code>Swagger</code>
Adds information for the API.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| title | <code>string</code> | the title of the API |
| version | <code>string</code> | the version of the API |
| description | <code>string</code> | the description of the API |

**Example**  
```js
swagger.info('My API', '1.0', 'This is *API*');
```
<a name="module_openapi-doc..Swagger+host"></a>

#### swagger.host(name)
Sets the host for the API

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| name | <code>string</code> | the hostname of the API, e.g. 'localhost' |

<a name="module_openapi-doc..Swagger+license"></a>

#### swagger.license(name)
Sets the license for the API

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| name | <code>string</code> | the license name |

<a name="module_openapi-doc..Swagger+contact"></a>

#### swagger.contact(name, [email])
Sets the contact name and email

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| name | <code>string</code> | the contact name |
| [email] | <code>string</code> | the contact email |

<a name="module_openapi-doc..Swagger+termsOfService"></a>

#### swagger.termsOfService(name)
Sets the terms of service for the API

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| name | <code>string</code> | the license name |

<a name="module_openapi-doc..Swagger+basePath"></a>

#### swagger.basePath(path)
Sets the API base path

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| path | <code>string</code> | the API base path |

<a name="module_openapi-doc..Swagger+schemes"></a>

#### swagger.schemes(schemes)
Sets the schemes for the API

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| schemes | <code>array</code> | An array of http schemes |

<a name="module_openapi-doc..Swagger+securityDefinition"></a>

#### swagger.securityDefinition(options, handler) ⇒ <code>Swagger</code>
Adds a Security Definition.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| options | <code>object</code> | The options for this security definition. See: http://swagger.io/specification/#securityDefinitionsObject |
| handler | <code>customAuthentication</code> | The middleware handler function. security definition. |

**Example**  
```javascript
swagger.securityDefinition(
    'basicAuth',
    {
         type: 'basic',
         description: 'Requires username:password'
    },
    (req) => {
         return true;
    }
});
// Assign security definition globally.
swagger.security('basicAuth');
```
<a name="module_openapi-doc..Swagger+security"></a>

#### swagger.security(definitionNames) ⇒ <code>Swagger</code>
Adds a Security Requirement to the current method.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| definitionNames | <code>array</code> | An array of the Security Definition names to apply.                                  If empty then no security. |

<a name="module_openapi-doc..Swagger+nosecurity"></a>

#### swagger.nosecurity()
Sets no security on the current method.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Example**  
```js
swagger.get('/foos/:id')
    .nosecurity();
```
<a name="module_openapi-doc..Swagger+schema"></a>

#### swagger.schema(name, spec) ⇒ <code>Swagger</code>
Adds a schema definition to the API.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| name | <code>string</code> | The type name. |
| spec | <code>object</code> | A valid JSON schema draft 04 spec. |

**Example**  
```javascript
const spec = { type: 'object', properties: { name: { type: 'string' } } };
swagger.schema('Item', spec)
    .get('/items')
    .response(200, 'Success', 'Item', true);
swagger.schema('Item', spec)
    .get('/items/:id')
    .response(200, 'Success', 'Item');
```
<a name="module_openapi-doc..Swagger+schemas"></a>

#### swagger.schemas()
Adds multiple schema to the API.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
<a name="module_openapi-doc..Swagger+post"></a>

#### swagger.post(path) ⇒ <code>Swagger</code>
Creates a post method for the specified path.  Use Express style routing.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| path | <code>string</code> | The path for the method. |

**Example**  
```js
swagger.post('/foos');
```
<a name="module_openapi-doc..Swagger+get"></a>

#### swagger.get(path) ⇒ <code>Swagger</code>
Creates a get method for the specified path.  Use Express style routing.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| path | <code>string</code> | The path for the method. |

**Example**  
```js
swagger.get('/foos/:id');
```
<a name="module_openapi-doc..Swagger+put"></a>

#### swagger.put(path) ⇒ <code>Swagger</code>
Creates a put method for the specified path.  Use Express style routing.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| path | <code>string</code> | The path for the method. |

**Example**  
```js
swagger.put('/foos/:id');
```
<a name="module_openapi-doc..Swagger+delete"></a>

#### swagger.delete(path) ⇒ <code>Swagger</code>
Creates a delete method for the specified path.  Use Express style routing.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| path | <code>string</code> | The path for the method. |

**Example**  
```js
swagger.delete('/foos/:id');
```
<a name="module_openapi-doc..Swagger+patch"></a>

#### swagger.patch(path) ⇒ <code>Swagger</code>
Creates a patch method for the specified path.  Use Express style routing.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| path | <code>string</code> | The path for the method. |

**Example**  
```js
swagger.patch('/foos/:id');
```
<a name="module_openapi-doc..Swagger+summary"></a>

#### swagger.summary(summary) ⇒ <code>Swagger</code>
Sets the summary for the current method.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| summary | <code>string</code> | The summary for the method. |

**Example**  
```js
swagger.delete('/foos/:id').summary('Deletes foo.');
```
<a name="module_openapi-doc..Swagger+description"></a>

#### swagger.description(description) ⇒ <code>Swagger</code>
Sets the description for the current method.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| description | <code>string</code> | The description for the method. |

**Example**  
```js
swagger.delete('/foos/:id').description('Deletes foo');
```
<a name="module_openapi-doc..Swagger+operationId"></a>

#### swagger.operationId(name) ⇒ <code>Swagger</code>
Sets the operationId for the current method.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| name | <code>string</code> | The name for the method. |

**Example**  
```js
swagger.delete('/foos/:id').operationId('DeleteFoo');
```
<a name="module_openapi-doc..Swagger+tag"></a>

#### swagger.tag(name) ⇒ <code>Swagger</code>
Adds a tag to the current method.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| name | <code>string</code> | The name for the method. |

**Example**  
```js
swagger.delete('/foos/:id').tag('foo');
```
<a name="module_openapi-doc..Swagger+tags"></a>

#### swagger.tags(tags) ⇒ <code>Swagger</code>
Adds multiple tags to the current method.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| tags | <code>Array.&lt;string&gt;</code> | The tags for the method. |

**Example**  
```js
swagger.delete('/foos/:id').tags(['foo', 'bar']);
```
<a name="module_openapi-doc..Swagger+body"></a>

#### swagger.body(type, description) ⇒ <code>Swagger</code>
Convenience method to add a body parameter to the current method.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| type | <code>string</code> | The type of object (not full ref), e.g. "Type" |
| description | <code>string</code> | The description of the body parameter. |

**Example**  
```js
swagger.post('/foo').body('Foo', 'Foo to create');
```
<a name="module_openapi-doc..Swagger+parameter"></a>

#### swagger.parameter(param) ⇒ <code>Swagger</code>
Adds a parameter to the current method.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| param | <code>object</code> | A valid Swagger parameter specification. |

**Example**  
```js
swagger.post('/foo').param({
	 in: 'path',
	 name: 'foo',
	 type: 'string',
	 description: 'My foo param'});
```
<a name="module_openapi-doc..Swagger+parameters"></a>

#### swagger.parameters(parameters)
Sets multiple parameters on the current method.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| parameters | <code>array</code> | A valid Swagger parameters array. |

<a name="module_openapi-doc..Swagger+consumes"></a>

#### swagger.consumes(mimeType, forceGlobal) ⇒ <code>Swagger</code>
Adds a consumes to either the current method or the doc.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| mimeType | <code>string</code> &#124; <code>Array.&lt;string&gt;</code> | The mime-type that can be consumed. |
| forceGlobal | <code>boolean</code> | Write to the document level consumes even if in a path. |

<a name="module_openapi-doc..Swagger+produces"></a>

#### swagger.produces(mimeType, forceGlobal) ⇒ <code>Swagger</code>
Adds a produces to either the current method or the doc.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| mimeType | <code>string</code> &#124; <code>Array.&lt;string&gt;</code> | The mime-type that can be consumed. |
| forceGlobal | <code>boolean</code> | Write to the document level produces even if in a path. |

<a name="module_openapi-doc..Swagger+response"></a>

#### swagger.response(code, [description], [type], [isArray], [headers]) ⇒ <code>Swagger</code>
Adds a response to the current method.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| code | <code>number</code> | The HTTP response code. |
| [description] | <code>string</code> | Optional description. 		If not specified, uses the standard HTTP response string. |
| [type] | <code>string</code> | Optional type (to be used in `$ref`). |
| [isArray] | <code>boolean</code> | Optional indicator that the repsonse is an array of `type`. |
| [headers] | <code>array</code> | Optional headers to include in the response. |

<a name="module_openapi-doc..Swagger+responses"></a>

#### swagger.responses(repsonses)
Sets multiple response on the current method.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| repsonses | <code>object</code> | A valid Swagger responses object. |

<a name="module_openapi-doc..Swagger+action"></a>

#### swagger.action(handler) ⇒ <code>Swagger</code>
Applies an action to the current method to be used with Express.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>Swagger</code> - The current object (this).  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| handler | <code>expressHandlerCallback</code> | The Express handler function. |

<a name="module_openapi-doc..Swagger+merge"></a>

#### swagger.merge(swagger, [prefix])
Merges a well defined swagger document into this one by merging
all definitions and paths found into this document.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| swagger | <code>object</code> | A well defined swagger document. |
| [prefix] | <code>string</code> | All paths will be prefixed with `prefix`. |

<a name="module_openapi-doc..Swagger+paths"></a>

#### swagger.paths(paths, [prefix])
Merges a well defined swagger paths into this one by merging
the paths found within this document.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| paths | <code>object</code> | A well defined swagger paths object. |
| [prefix] | <code>string</code> | All paths will be prefixed with `prefix`. |

<a name="module_openapi-doc..Swagger+apidoc"></a>

#### swagger.apidoc() ⇒ <code>object</code>
Returns the Swagger 2.0 API document.

**Kind**: instance method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>object</code> - Swagger 2.0 API document.  
**Access**: public  
<a name="module_openapi-doc..Swagger.endpointToExpress"></a>

#### Swagger.endpointToExpress(str) ⇒ <code>string</code>
Rewrites path string from Swagger format `/path/{id}` to Express format `/path/:id`.

**Kind**: static method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Returns**: <code>string</code> - Rewritten string  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| str | <code>string</code> | The swagger path to convert. |

<a name="module_openapi-doc..Swagger.forEachAction"></a>

#### Swagger.forEachAction(swagger, callback)
Iterates over each endpoint in the swagger document.  Useful for binding
to Express.

**Kind**: static method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| swagger | <code>Swagger</code> | The swagger document. |
| callback | <code>forEachActionCallback</code> | Called for each endpoint action. |

<a name="module_openapi-doc..Swagger.actionMiddleware"></a>

#### Swagger.actionMiddleware(swagger, verb, path)
Gets the Swagger action middleware function for Express.

**Kind**: static method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| swagger | <code>Swagger</code> | The swagger document. |
| verb | <code>string</code> | The HTTP verb. |
| path | <code>string</code> | The HTTP path. |

<a name="module_openapi-doc..Swagger.securityMiddleware"></a>

#### Swagger.securityMiddleware(swagger, verb, path)
Gets the Swagger security middleware function for Express.

**Kind**: static method of <code>[Swagger](#module_openapi-doc..Swagger)</code>  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| swagger | <code>Swagger</code> | The swagger document. |
| verb | <code>string</code> | The HTTP verb. |
| path | <code>string</code> | The HTTP path. |

<a name="module_openapi-doc..customAuthentication"></a>

### openapi-doc~customAuthentication ⇒ <code>boolean</code>
Callback function for custom authentication.

**Kind**: inner typedef of <code>[openapi-doc](#module_openapi-doc)</code>  
**Returns**: <code>boolean</code> - Return `true` if valid, or `false` if invalid.  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| req | <code>object</code> | The express request object. |

<a name="module_openapi-doc..expressHandlerCallback"></a>

### openapi-doc~expressHandlerCallback : <code>function</code>
Callback for handling Express action.

**Kind**: inner typedef of <code>[openapi-doc](#module_openapi-doc)</code>  

| Param | Type | Description |
| --- | --- | --- |
| request | <code>object</code> | The Express request object. |
| response | <code>object</code> | The Express response object. |

<a name="module_openapi-doc..forEachActionCallback"></a>

### openapi-doc~forEachActionCallback : <code>function</code>
Callback for iterating over Swagger endpoint actions.

**Kind**: inner typedef of <code>[openapi-doc](#module_openapi-doc)</code>  

| Param | Type | Description |
| --- | --- | --- |
| path | <code>string</code> | The endpoint path. |
| verb | <code>string</code> | The endpoint verb. |


## Dependencies

Package | Version | Dev
--- |:---:|:---:
[url-join](https://www.npmjs.com/package/url-join) | ^1.1.0 | ✖
[babel-cli](https://www.npmjs.com/package/babel-cli) | ^6.3.17 | ✔
[babel-eslint](https://www.npmjs.com/package/babel-eslint) | ^6.1.2 | ✔
[babel-preset-es2015](https://www.npmjs.com/package/babel-preset-es2015) | * | ✔
[chai](https://www.npmjs.com/package/chai) | ^3.5.0 | ✔
[cross-env](https://www.npmjs.com/package/cross-env) | ^3.1.3 | ✔
[eslint](https://www.npmjs.com/package/eslint) | ^3.15.0 | ✔
[eslint-config-airbnb](https://www.npmjs.com/package/eslint-config-airbnb) | ^14.1.0 | ✔
[eslint-plugin-import](https://www.npmjs.com/package/eslint-plugin-import) | ^2.2.0 | ✔
[eslint-plugin-jsx-a11y](https://www.npmjs.com/package/eslint-plugin-jsx-a11y) | ^4.0.0 | ✔
[eslint-plugin-react](https://www.npmjs.com/package/eslint-plugin-react) | ^6.9.0 | ✔
[istanbul](https://www.npmjs.com/package/istanbul) | ^0.4.5 | ✔
[jsdoc-to-markdown](https://www.npmjs.com/package/jsdoc-to-markdown) | ^3.0.0 | ✔
[mocha](https://www.npmjs.com/package/mocha) | ^3.0.2 | ✔
[node-mv](https://www.npmjs.com/package/node-mv) | ^0.1.3 | ✔
[node-readme](https://www.npmjs.com/package/node-readme) | ^0.1.8 | ✔
[nsp](https://www.npmjs.com/package/nsp) | ^2.6.3 | ✔
[nsp-formatter-writefile](https://www.npmjs.com/package/nsp-formatter-writefile) | ^1.0.0 | ✔
[retire](https://www.npmjs.com/package/retire) | ^1.2.12 | ✔
[rimraf](https://www.npmjs.com/package/rimraf) | ^2.5.4 | ✔
[swagger-parser](https://www.npmjs.com/package/swagger-parser) | ^3.4.1 | ✔


## Author

Axway <support@axway.com> https://axway.com

## License

This code is closed source and Confidential and Proprietary to Appcelerator, Inc. All Rights Reserved. This code MUST not be modified, copied or otherwise redistributed without express written permission of Appcelerator. This file is licensed as part of the Appcelerator Platform and governed under the terms of the Appcelerator license agreement. Your right to use this software terminates when you terminate your Appcelerator subscription.
